# Usage and examples

The following notebooks should serve as a guide to using `rm-lite`. These
notebooks are run during the automated testing, so if you can read this the
examples should work as written.

```{toctree}
:maxdepth: 1
:caption: Example notebooks:
examples/rmsynth_1d.ipynb
examples/rmclean_1d.ipynb
examples/rmsynth_2d.ipynb

```
